@@ -1,9 +1,9 @@
 #!/usr/bin/ruby
 # DocDiff: word/char-oriented text comparison utility
-# 2002-06-27 Thu ... 200x-xx-xx xxx
+# 2002-06-27 Thu ... 201x-xx-xx xxx
 # Hisashi MORITA
-# requirement for runtime: Ruby (> 1.6)
-# requirement for testing: above plus Uconv by Yoshidam
+# requirement for runtime: Ruby (> 1.8)
+# requirement for testing: above plus iconv
 
 require 'docdiff/difference'
 require 'docdiff/document'
@@ -12,8 +12,8 @@ require 'optparse'
 
 class DocDiff
 
-  AppVersion = '0.3.4'
-  Author = "Copyright (C) 2002-200x Hisashi MORITA.\n" +
+  AppVersion = '0.4.0'
+  Author = "Copyright (C) 2002-201x Hisashi MORITA.\n" +
            "diff library originates from Ruby/CVS by TANAKA Akira.\n"
   License = "This software is licensed under so-called modified BSD license.\n" +
             "See the document for detail.\n"
@@ -57,9 +57,9 @@ class DocDiff
     words = Difference.new
     lines.each{|line|
       if line.first == :change_elt
-        before_change = Document.new(line[1].to_s,
+        before_change = Document.new(line[1].join,
                                      doc1.encoding, doc1.eol)
-        after_change  = Document.new(line[2].to_s,
+        after_change  = Document.new(line[2].join,
                                      doc2.encoding, doc2.eol)
         Difference.new(before_change.split_to_word,
                        after_change.split_to_word).each{|word|
@@ -78,9 +78,9 @@ class DocDiff
     lines_and_words = Difference.new
     lines.each{|line|
       if line.first == :change_elt
-        before_change = Document.new(line[1].to_s,
+        before_change = Document.new(line[1].join,
                                      doc1.encoding, doc1.eol)
-        after_change  = Document.new(line[2].to_s,
+        after_change  = Document.new(line[2].join,
                                      doc2.encoding, doc2.eol)
         Difference.new(before_change.split_to_word,
                        after_change.split_to_word).each{|word|
@@ -93,8 +93,8 @@ class DocDiff
     lines_words_and_chars = Difference.new
     lines_and_words.each{|line_or_word|
       if line_or_word.first == :change_elt
-        before_change = Document.new(line_or_word[1].to_s, doc1.encoding, doc1.eol)
-        after_change  = Document.new(line_or_word[2].to_s, doc2.encoding, doc2.eol)
+        before_change = Document.new(line_or_word[1].join, doc1.encoding, doc1.eol)
+        after_change  = Document.new(line_or_word[2].join, doc2.encoding, doc2.eol)
         Difference.new(before_change.split_to_char, after_change.split_to_char).each{|char|
           lines_words_and_chars << char
         }
@@ -159,7 +159,7 @@ class DocDiff
         raise "Unsupported output format: #{option[:format].inspect}."
       end
     end
-    result.to_s
+    result.join
   end
 
   def process_config_file(filename)
@@ -207,7 +207,7 @@ if $0 == __FILE__
                  possible_resolutions = ['line', 'word', 'char'],
                  'specify resolution (granularity)',
                  possible_resolutions.join('|') + ' (default is word)'
-                ){|clo[:resolution]| clo[:resolution] ||= "word"}
+                ){|s| clo[:resolution] = (s || "word")}
     o.def_option('--line', 'set resolution to line'){clo[:resolution] = "line"}
     o.def_option('--word', 'set resolution to word'){clo[:resolution] = "word"}
     o.def_option('--char', 'set resolution to char'){clo[:resolution] = "char"}
@@ -216,7 +216,7 @@ if $0 == __FILE__
                  possible_encodings = ['ASCII','EUC-JP','Shift_JIS','UTF-8','auto'],
                  'specify character encoding',
                  possible_encodings.join('|'), "(default is auto. try ASCII for single byte encodings such as ISO-8859-X)"
-                ){|clo[:encoding]| clo[:encoding] ||= "auto"}
+                ){|s| clo[:encoding] = (s || "auto")}
     o.def_option('--ascii', 'same as --encoding=ASCII'){clo[:encoding] = "ASCII"}
     o.def_option('--iso8859x', 'same as --encoding=ASCII'){clo[:encoding] = "ASCII"}
     o.def_option('--eucjp', 'same as --encoding=EUC-JP'){clo[:encoding] = "EUC-JP"}
@@ -227,7 +227,7 @@ if $0 == __FILE__
                  possible_eols = ['CR','LF','CRLF','auto'],
                  'specify end-of-line character',
                  possible_eols.join('|') + ' (default is auto)'
-                ){|clo[:eol]| clo[:eol] ||= "auto"}
+                ){|s| clo[:eol] = (s || "auto")}
     o.def_option('--cr', 'same as --eol=CR'){clo[:eol] = "CR"}
     o.def_option('--lf', 'same as --eol=LF'){clo[:eol] = "LF"}
     o.def_option('--crlf', 'same as --eol=CRLF'){clo[:eol] = "CRLF"}
@@ -238,7 +238,7 @@ if $0 == __FILE__
                  possible_formats.join('|'),
                  "(default is html)",
                  '(user tags can be defined in config file)'
-                ){|clo[:format]| clo[:format] ||= "manued"}
+                ){|s| clo[:format] = (s || "manued")}
     o.def_option('--tty', 'same as --format=tty'){clo[:format] = "tty"}
     o.def_option('--manued', 'same as --format=manued'){clo[:format] = "manued"}
     o.def_option('--html', 'same as --format=html'){clo[:format] = "html"}
@@ -246,7 +246,8 @@ if $0 == __FILE__
     o.def_option('--stat', 'same as --format=stat (not supported yet)'){clo[:format] = "stat"}
 
     o.def_option('--label LABEL', '-L LABEL',
-                 'Use label instead of filename (not supported yet)'){|clo[:label1], clo[:label2]|}
+                 'Use label instead of filename (not supported yet)'
+                 ){|s1, s2| clo[:label1], clo[:label2] = s1, s2}
 
     o.def_option('--digest', 'digest output, do not show all'){clo[:digest] = true}
     o.def_option('--summary', 'same as --digest'){clo[:digest] = true}
