@@ -3,11 +3,10 @@
 # To use, include to String, or extend String.
 # 2003- Hisashi MORITA
 
-require 'iconv'
 module CharString
 
-  Encodings = Hash.new
-  EOLChars = Hash.new  # End-of-line characters, such as CR, LF, CRLF.
+  Encodings = {}
+  EOLChars = {}  # End-of-line characters, such as CR, LF, CRLF.
 
   def initialize(string)
 =begin unnecessary
@@ -17,21 +16,6 @@ module CharString
     super
   end
 
-  def encoding()
-    @encoding
-#     if @encoding
-#       @encoding
-#     else
-#       @encoding = CharString.guess_encoding(self)
-#       # raise "encoding is not set.\n"
-#     end
-  end
-
-  def encoding=(cs)
-    @encoding = cs
-    extend Encodings[@encoding]  # ; p "Hey, I extended #{Encodings[@encoding]}!"
-  end
-
   def eol()
     @eol
 #     if @eol
@@ -84,7 +68,212 @@ module CharString
     EOLChars[mod::EOL] = mod
   end
 
-  # returns nil, 'ASCII', 'JIS', 'EUC-JP', 'Shift_JIS', 'UTF-8', or 'UNKNOWN'
+  def CharString.guess_eol(string)
+    # returns 'CR', 'LF', 'CRLF', 'UNKNOWN'(binary), 
+    # 'NONE'(1-line), or nil
+    return nil if string == nil  #=> nil (argument missing)
+    eol_counts = {'CR'   => string.scan(/(\r)(?!\n)/o).size,
+                  'LF'   => string.scan(/(?:\A|[^\r])(\n)/o).size,
+                  'CRLF' => string.scan(/(\r\n)/o).size}
+    eol_counts.delete_if{|eol, count| count == 0}  # Remove missing EOL
+    eols = eol_counts.keys
+    eol_variety = eols.size  # numbers of flavors found
+    if eol_variety == 1          # Only one type of EOL found
+      return eols[0]         #=> 'CR', 'LF', or 'CRLF'
+    elsif eol_variety == 0       # No EOL found
+      return 'NONE'              #=> 'NONE' (might be 1-line file)
+    else                         # Multiple types of EOL found
+      return 'UNKNOWN'           #=> 'UNKNOWN' (might be binary data)
+    end
+  end
+
+  def CharString.ruby_m17n?
+    "".respond_to?(:force_encoding)
+  end
+
+  # Note that some languages (like Japanese) do not have 'word' or 'phrase', 
+  # thus some of the following methods are not 'linguistically correct'.
+
+  def count_byte()
+    split_to_byte().size
+  end
+
+  def count_char()  # eol = 1 char
+    split_to_char().size
+  end
+
+  def count_graph_char()
+    count_latin_graph_char() + count_ja_graph_char()
+  end
+
+  def count_blank_char()
+    count_latin_blank_char() + count_ja_blank_char()
+  end
+
+  def count_word()
+    split_to_word().size
+  end
+
+  def count_valid_word()
+    count_latin_valid_word() + count_ja_valid_word()
+  end
+
+  def count_line()  # this is common to all encodings.
+    split_to_line.size
+  end
+
+  def count_empty_line()
+    split_to_line.collect{|line|
+      line if /^(?:#{eol_char})|^$/m.match line
+    }.compact.size
+  end
+
+if ruby_m17n?
+  # for Ruby-1.9
+  def encoding()
+    String.new(self).encoding.to_s
+  end
+
+  def encoding=(cs)
+    force_encoding(cs) if self
+  end
+
+  def CharString.guess_encoding(string)
+    if string
+      string.encoding.to_s
+    else
+      nil
+    end
+  end
+
+  def split_to_byte()
+    encode("ASCII-8BIT").scan(/./nm)
+  end
+
+  def split_to_char()
+    if eol_char  # sometimes string has no end-of-line char
+      encode('UTF-8').scan(Regexp.new("(?:#{eol_char})|(?:.)", 
+                      Regexp::MULTILINE)
+      ).map{|e| e.encode(self.encoding)}
+    else                  # it seems that no EOL module was extended...
+      encode('UTF-8').scan(Regexp.new("(?:.)", 
+                      Regexp::MULTILINE)
+      ).map{|e| e.encode(self.encoding)}
+    end
+  end
+
+  def count_latin_graph_char()
+    encode('UTF-8').scan(Regexp.new("[#{Encodings['UTF-8']::GRAPH}]", 
+                    Regexp::MULTILINE)
+    ).size
+  end
+
+  def count_ja_graph_char()
+    encode('UTF-8').scan(Regexp.new("[#{Encodings['UTF-8']::JA_GRAPH}]", 
+                    Regexp::MULTILINE)
+    ).size
+  end
+
+  def count_latin_blank_char()
+    encode('UTF-8').scan(Regexp.new("[#{Encodings['UTF-8']::BLANK}]", 
+                    Regexp::MULTILINE)
+    ).size
+  end
+
+  def count_ja_blank_char()
+    encode('UTF-8').scan(Regexp.new("[#{Encodings['UTF-8']::JA_BLANK}]", 
+                    Regexp::MULTILINE)
+    ).size
+  end
+
+  def split_to_word()
+    encode('UTF-8').scan(Regexp.new(Encodings['UTF-8']::WORD_REGEXP_SRC, 
+                    Regexp::MULTILINE)
+    ).map{|e| e.encode(self.encoding)}
+  end
+
+  def count_latin_word()
+    split_to_word.collect{|word|
+      word if Regexp.new("[#{Encodings['UTF-8']::PRINT}]", 
+                         Regexp::MULTILINE).match word.encode('UTF-8')
+    }.compact.size
+  end
+
+  def count_ja_word()
+    split_to_word.collect{|word|
+      word if Regexp.new("[#{Encodings['UTF-8']::JA_PRINT}]", 
+                         Regexp::MULTILINE).match word.encode('UTF-8')
+    }.compact.size
+  end
+
+  def count_latin_valid_word()
+    split_to_word.collect{|word|
+      word if Regexp.new("[#{Encodings['UTF-8']::ALNUM}]", 
+                         Regexp::MULTILINE).match word.encode('UTF-8')
+    }.compact.size
+  end
+
+  def count_ja_valid_word()
+    split_to_word.collect{|word|
+      word if Regexp.new("[#{Encodings['UTF-8']::JA_GRAPH}]", 
+                         Regexp::MULTILINE).match word.encode('UTF-8')
+    }.compact.size
+  end
+
+  def split_to_line()
+    raise "EOLChars[eol] is #{EOLChars[eol].inspect}: eol not specified or auto-detection failed." unless EOLChars[eol]
+    if defined? eol_char
+      encode('UTF-8').scan(Regexp.new(".*?#{eol_char}|.+", 
+                      Regexp::MULTILINE)
+      ).map{|e| e.encode(self.encoding)}
+    else
+      encode('UTF-8').scan(Regexp.new(".+", 
+                      Regexp::MULTILINE)
+      ).map{|e| e.encode(self.encoding)}
+    end
+  end
+
+  def count_graph_line()
+    split_to_line.collect{|line|
+      line if Regexp.new("[#{Encodings['UTF-8']::GRAPH}" + 
+                         "#{Encodings['UTF-8']::JA_GRAPH}]", 
+                         Regexp::MULTILINE).match line.encode('UTF-8')
+    }.compact.size
+  end
+
+  def count_blank_line()
+    split_to_line.collect{|line|
+      line if Regexp.new("^[#{Encodings['UTF-8']::BLANK}" + 
+                         "#{Encodings['UTF-8']::JA_BLANK}]+(?:#{eol_char})?", 
+                         Regexp::MULTILINE).match line.encode('UTF-8')
+    }.compact.size
+  end
+
+  # load encoding modules
+  require 'docdiff/encoding/en_ascii'
+  require 'docdiff/encoding/ja_eucjp'
+  require 'docdiff/encoding/ja_sjis'
+  require 'docdiff/encoding/ja_utf8'
+else
+  # for Ruby-1.8
+  require 'iconv'
+
+  def encoding()
+    @encoding
+#     if @encoding
+#       @encoding
+#     else
+#       @encoding = CharString.guess_encoding(self)
+#       # raise "encoding is not set.\n"
+#     end
+  end
+
+  def encoding=(cs)
+    @encoding = cs
+    extend Encodings[@encoding]  # ; p "Hey, I extended #{Encodings[@encoding]}!"
+  end
+
+  # returns nil, 'US-ASCII', 'JIS', 'EUC-JP', 'Shift_JIS', 'UTF-8', or 'UNKNOWN'
   def CharString.guess_encoding(string)
     return nil if string == nil
     result_using_pureruby = CharString.guess_encoding_using_pureruby(string)
@@ -96,7 +285,7 @@ module CharString
     end
   end
 
-  # returns nil, 'ASCII', 'JIS', 'EUC-JP', 'Shift_JIS', 'UTF-8', or 'UNKNOWN'
+  # returns nil, 'US-ASCII', 'JIS', 'EUC-JP', 'Shift_JIS', 'UTF-8', or 'UNKNOWN'
   def CharString.guess_encoding_using_pureruby(string)
     return nil if string == nil
 
@@ -132,7 +321,7 @@ module CharString
     when 0 < jis_escseq_count                 # JIS escape sequense found
       guessed_encoding = 'JIS'
     when ascii_match_length == string.length  # every char is ASCII (but not JIS)
-      guessed_encoding = 'ASCII'
+      guessed_encoding = 'US-ASCII'
     else
       case
       when eucjp_match_length < (string.length / 2) && 
@@ -170,7 +359,7 @@ module CharString
     when string == nil
       nil
     when valid_as_ascii
-      "ASCII"
+      "US-ASCII"
     when valid_as_jis  # Iconv sometimes recognizes JIS for ASCII, ignoring JIS escape sequence.
       "JIS"
     when valid_as_eucjp
@@ -183,6 +372,7 @@ module CharString
       "UNKNOWN"
     end
   end
+
   def CharString.valid_as(encoding_name, string)
     begin
       Iconv.iconv(encoding_name, encoding_name, string)
@@ -192,6 +382,7 @@ module CharString
       return true
     end
   end
+
   def CharString.invalid_as(encoding_name, string)
     if CharString.valid_as(encoding_name, string)
       false
@@ -200,36 +391,9 @@ module CharString
     end
   end
 
-  def CharString.guess_eol(string)
-    # returns 'CR', 'LF', 'CRLF', 'UNKNOWN'(binary), 
-    # 'NONE'(1-line), or nil
-    return nil if string == nil  #=> nil (argument missing)
-    eol_counts = {'CR'   => string.scan(/(\r)(?!\n)/no).size,
-                  'LF'   => string.scan(/(?:\A|[^\r])(\n)/no).size,
-                  'CRLF' => string.scan(/(\r\n)/no).size}
-    eol_counts.delete_if{|eol, count| count == 0}  # Remove missing EOL
-    eols = eol_counts.keys
-    eol_variety = eols.size  # numbers of flavors found
-    if eol_variety == 1          # Only one type of EOL found
-      return eols[0]         #=> 'CR', 'LF', or 'CRLF'
-    elsif eol_variety == 0       # No EOL found
-      return 'NONE'              #=> 'NONE' (might be 1-line file)
-    else                         # Multiple types of EOL found
-      return 'UNKNOWN'           #=> 'UNKNOWN' (might be binary data)
-    end
-  end
-
-  # Note that some languages (like Japanese) do not have 'word' or 'phrase', 
-  # thus some of the following methods are not 'linguistically correct'.
-
   def split_to_byte()
     scan(/./nm)
   end
-  alias to_bytes split_to_byte
-
-  def count_byte()
-    split_to_byte().size
-  end
 
   def split_to_char()
     raise "Encodings[encoding] is #{Encodings[encoding].inspect}: encoding not specified or auto-detection failed." unless Encodings[encoding]
@@ -246,11 +410,6 @@ module CharString
       )
     end
   end
-  alias to_chars split_to_char
-
-  def count_char()  # eol = 1 char
-    split_to_char().size
-  end
 
   def count_latin_graph_char()
     raise "Encodings[encoding] is #{Encodings[encoding].inspect}: encoding not specified or auto-detection failed." unless Encodings[encoding]
@@ -270,10 +429,6 @@ module CharString
     ).size
   end
 
-  def count_graph_char()
-    count_latin_graph_char() + count_ja_graph_char()
-  end
-
   def count_latin_blank_char()
     scan(Regexp.new("[#{Encodings[encoding]::BLANK}]", 
                     Regexp::MULTILINE, 
@@ -288,10 +443,6 @@ module CharString
     ).size
   end
 
-  def count_blank_char()
-    count_latin_blank_char() + count_ja_blank_char()
-  end
-
   def split_to_word()
     raise "Encodings[encoding] is #{Encodings[encoding].inspect}: encoding not specified or auto-detection failed." unless Encodings[encoding]
     # raise "EOLChars[eol] is #{EOLChars[eol].inspect}: eol not specified or auto-detection failed." unless EOLChars[eol]
@@ -300,11 +451,6 @@ module CharString
                     encoding.sub(/ASCII/i, 'none'))
     )
   end
-  alias to_words split_to_word
-
-  def count_word()
-    split_to_word().size
-  end
 
   def count_latin_word()
     split_to_word.collect{|word|
@@ -338,10 +484,6 @@ module CharString
     }.compact.size
   end
 
-  def count_valid_word()
-    count_latin_valid_word() + count_ja_valid_word()
-  end
-
   def split_to_line()
 #     scan(Regexp.new(".*?#{eol_char}|.+", 
 #                     Regexp::MULTILINE, 
@@ -361,11 +503,6 @@ module CharString
       )
     end
   end
-  alias to_lines split_to_line
-
-  def count_line()  # this is common to all encodings.
-    split_to_line.size
-  end
 
   def count_graph_line()
     split_to_line.collect{|line|
@@ -376,12 +513,6 @@ module CharString
     }.compact.size
   end
 
-  def count_empty_line()
-    split_to_line.collect{|line|
-      line if /^(?:#{eol_char})|^$/em.match line
-    }.compact.size
-  end
-
   def count_blank_line()
     split_to_line.collect{|line|
       line if Regexp.new("^[#{Encodings[encoding]::BLANK}" + 
@@ -396,6 +527,11 @@ module CharString
   require 'docdiff/encoding/ja_eucjp'
   require 'docdiff/encoding/ja_sjis'
   require 'docdiff/encoding/ja_utf8'
+end # end ruby_m17n?
+  alias to_bytes split_to_byte
+  alias to_chars split_to_char
+  alias to_words split_to_word
+  alias to_lines split_to_line
 
   module CR
     EOL = 'CR'
