@@ -4,7 +4,7 @@
 module CharString
   module ASCII
 
-    Encoding = "ASCII"
+    Encoding = "US-ASCII"
 
     CNTRL =     "\x00\x01\x02\x03\x04\x05\x06\x07\x08\x09" \
                 "\x0a\x0b\x0c\x0d\x0e\x0f\x10\x11\x12\x13" \
