@@ -1,8 +1,8 @@
 #!/usr/bin/ruby
+# -*- coding: euc-jp; -*-
 require 'test/unit'
 require 'docdiff/charstring'
 require 'nkf'
-require 'uconv'
 
 class TC_CharString < Test::Unit::TestCase
 
@@ -13,7 +13,7 @@ class TC_CharString < Test::Unit::TestCase
   # test encoding module registration
   def test_encoding_ascii()
     str = "foo".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     expected = CharString::ASCII
     assert_equal(expected, CharString::Encodings[str.encoding])
   end
@@ -99,63 +99,63 @@ class TC_CharString < Test::Unit::TestCase
   # test eol split_to_line() method
   def test_cr_split_to_line()
     str = "foo\rbar\r".extend CharString
-    encoding, eol = "ASCII", "CR"
+    encoding, eol = "US-ASCII", "CR"
     str.encoding, str.eol = encoding, eol
     expected = ["foo\r", "bar\r"]
     assert_equal(expected, str.split_to_line)
   end
   def test_cr_split_to_line_chomped_lastline()
     str = "foo\rbar".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CR"
     expected = ["foo\r", "bar"]
     assert_equal(expected, str.split_to_line)
   end
   def test_cr_split_to_line_empty_line()
     str = "foo\r\rbar\r".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CR"
     expected = ["foo\r", "\r", "bar\r"]
     assert_equal(expected, str.split_to_line)
   end
   def test_lf_split_to_line()
     str = "foo\nbar\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "LF"
     expected = ["foo\n", "bar\n"]
     assert_equal(expected, str.split_to_line)
   end
   def test_lf_split_to_line_chomped_lastline()
     str = "foo\nbar".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "LF"
     expected = ["foo\n", "bar"]
     assert_equal(expected, str.split_to_line)
   end
   def test_lf_split_to_line_empty_line()
     str = "foo\n\nbar\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "LF"
     expected = ["foo\n", "\n", "bar\n"]
     assert_equal(expected, str.split_to_line)
   end
   def test_crlf_split_to_line()
     str = "foo\r\nbar\r\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = ["foo\r\n", "bar\r\n"]
     assert_equal(expected, str.split_to_line)
   end
   def test_crlf_split_to_line_chomped_lastline()
     str = "foo\r\nbar".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = ["foo\r\n", "bar"]
     assert_equal(expected, str.split_to_line)
   end
   def test_crlf_split_to_line_empty_line()
     str = "foo\r\n\r\nbar\r\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = ["foo\r\n", "\r\n", "bar\r\n"]
     assert_equal(expected, str.split_to_line)
@@ -164,156 +164,156 @@ class TC_CharString < Test::Unit::TestCase
   # test ASCII module
   def test_ascii_split_to_word()
     str = "foo bar".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     expected = ["foo ", "bar"]
     assert_equal(expected, str.split_to_word)
   end
   def test_ascii_split_to_word_withsymbol()
     str = "foo (bar) baz-baz".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     expected = ["foo ", "(bar) ", "baz-baz"]
     assert_equal(expected, str.split_to_word)
   end
   def test_ascii_split_to_word_withquote()
     str = "foo's 'foo' \"bar\" 'baz.'".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     expected = ["foo's ", "'foo' ", "\"bar\" ", "'baz.'"]
     assert_equal(expected, str.split_to_word)
   end
   def test_ascii_split_to_word_withlongspace()
     str = " foo  bar".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     expected = [" ", "foo ", " ", "bar"]
     assert_equal(expected, str.split_to_word)
   end
   def test_ascii_split_to_word_withdash()
     str = "foo -- bar, baz - quux".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     expected = ["foo ", "-- ", "bar, ", "baz ", "- ", "quux"]
     assert_equal(expected, str.split_to_word)
   end
   def test_ascii_split_to_char()
     str = "foo bar".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "LF"
     expected = ["f","o","o"," ","b","a","r"]
     assert_equal(expected, str.split_to_char)
   end
   def test_ascii_split_to_char_with_eol_cr()
     str = "foo bar\r".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CR"
     expected = ["f","o","o"," ","b","a","r","\r"]
     assert_equal(expected, str.split_to_char)
   end
   def test_ascii_split_to_char_with_eol_lf()
     str = "foo bar\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "LF"
     expected = ["f","o","o"," ","b","a","r","\n"]
     assert_equal(expected, str.split_to_char)
   end
   def test_ascii_split_to_char_with_eol_crlf()
     str = "foo bar\r\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = ["f","o","o"," ","b","a","r","\r\n"]
     assert_equal(expected, str.split_to_char)
   end
   def test_ascii_split_to_byte()
     str = "foo bar\r\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = ["f","o","o"," ","b","a","r","\r","\n"]
     assert_equal(expected, str.split_to_byte)
   end
   def test_ascii_count_byte()
     str = "foo bar\r\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = 9
     assert_equal(expected, str.count_byte)
   end
   def test_ascii_count_char()
     str = "foo bar\r\nbaz quux\r\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = 17
     assert_equal(expected, str.count_char)
   end
   def test_ascii_count_latin_graph_char()
     str = "foo bar\r\nbaz quux\r\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = 13
     assert_equal(expected, str.count_latin_graph_char)
   end
   def test_ascii_count_graph_char()
     str = "foo bar\r\nbaz quux\r\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = 13
     assert_equal(expected, str.count_graph_char)
   end
   def test_ascii_count_latin_blank_char()
     str = "foo bar\r\nbaz\tquux\r\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = 2
     assert_equal(expected, str.count_latin_blank_char)
   end
   def test_ascii_count_blank_char()
     str = "foo bar\r\nbaz\tquux\r\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = 2
     assert_equal(expected, str.count_blank_char)
   end
   def test_ascii_count_word()
     str = "foo bar   \r\nbaz quux\r\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = 6
     assert_equal(expected, str.count_word)
   end
   def test_ascii_count_latin_word()
     str = "foo bar   \r\nbaz quux\r\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = 5  # "  " is also counted as a word
     assert_equal(expected, str.count_latin_word)
   end
   def test_ascii_count_latin_valid_word()
     str = "1 foo   \r\n%%% ()\r\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = 2
     assert_equal(expected, str.count_latin_valid_word)
   end
   def test_ascii_count_line()
     str = "foo\r\nbar".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = 2
     assert_equal(expected, str.count_line)
   end
   def test_ascii_count_graph_line()
     str = "foo\r\n ".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = 1
     assert_equal(expected, str.count_graph_line)
   end
   def test_ascii_count_empty_line()
     str = "foo\r\n \r\n\t\r\n\r\n".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = 1
     assert_equal(expected, str.count_empty_line)
   end
   def test_ascii_count_blank_line()
     str = "\r\n \r\n\t\r\n ".extend CharString
-    str.encoding = "ASCII"
+    str.encoding = "US-ASCII"
     str.eol = "CRLF"
     expected = 3
     assert_equal(expected, str.count_blank_line)
@@ -677,176 +677,176 @@ class TC_CharString < Test::Unit::TestCase
 
   # test UTF8 module
   def test_utf8_split_to_word()
-    str = Uconv.euctou8("ܸʸfoo bar").extend CharString
+    str = NKF.nkf("-E -w", "ܸʸfoo bar").extend CharString
     str.encoding = "UTF-8"
-    expected = ["ܸ", "ʸ", "foo ", "bar"].collect{|c| Uconv.euctou8(c)}
+    expected = ["ܸ", "ʸ", "foo ", "bar"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, str.split_to_word)
   end
   def test_utf8_split_to_word_kanhira()
-    str = Uconv.euctou8("ܸʸ").extend CharString
+    str = NKF.nkf("-E -w", "ܸʸ").extend CharString
     str.encoding = "UTF-8"
-    expected = ["ܸ", "ʸ"].collect{|c| Uconv.euctou8(c)}
+    expected = ["ܸ", "ʸ"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, str.split_to_word)
   end
   def test_utf8_split_to_word_katahira()
-    str = Uconv.euctou8("ʤʸ").extend CharString
+    str = NKF.nkf("-E -w", "ʤʸ").extend CharString
     str.encoding = "UTF-8"
-    expected = ["ʤ", "ʸ"].collect{|c| Uconv.euctou8(c)}
+    expected = ["ʤ", "ʸ"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, str.split_to_word)
   end
   def test_utf8_split_to_word_kataonbiki()
-    str = Uconv.euctou8("ӡλ").extend CharString
+    str = NKF.nkf("-E -w", "ӡλ").extend CharString
     str.encoding = "UTF-8"
-    expected = ["ӡ", ""].collect{|c| Uconv.euctou8(c)}
+    expected = ["ӡ", ""].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, str.split_to_word)
   end
   def test_utf8_split_to_word_hiraonbiki()
-    str = Uconv.euctou8("ӡ").extend CharString
+    str = NKF.nkf("-E -w", "ӡ").extend CharString
     str.encoding = "UTF-8"
-    expected = ["", "ӡ"].collect{|c| Uconv.euctou8(c)}
+    expected = ["", "ӡ"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, str.split_to_word)
   end
   def test_utf8_split_to_word_latinmix()
-    str = Uconv.euctou8("ܸLatinʸ").extend CharString
+    str = NKF.nkf("-E -w", "ܸLatinʸ").extend CharString
     str.encoding = "UTF-8"
-    expected = ["ܸ", "Latin", "", "ʸ"].collect{|c| Uconv.euctou8(c)}
+    expected = ["ܸ", "Latin", "", "ʸ"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, str.split_to_word)
   end
   def test_utf8_split_to_char()
-    str = Uconv.euctou8("ܸa b").extend CharString
+    str = NKF.nkf("-E -w", "ܸa b").extend CharString
     str.encoding = "UTF-8" #<= needed to pass the test
     str.eol = "LF"        #<= needed to pass the test
-    expected = ["", "", "", "a", " ", "b"].collect{|c| Uconv.euctou8(c)}
+    expected = ["", "", "", "a", " ", "b"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, str.split_to_char)
   end
   def test_utf8_split_to_char_with_cr()
-    str = Uconv.euctou8("ܸa b\r").extend CharString
+    str = NKF.nkf("-E -w", "ܸa b\r").extend CharString
     str.encoding = "UTF-8" #<= needed to pass the test
     str.eol = "CR"
-    expected = ["","","","a"," ","b","\r"].collect{|c| Uconv.euctou8(c)}
+    expected = ["","","","a"," ","b","\r"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, str.split_to_char)
   end
   def test_utf8_split_to_char_with_lf()
-    str = Uconv.euctou8("ܸa b\n").extend CharString
+    str = NKF.nkf("-E -w", "ܸa b\n").extend CharString
     str.encoding = "UTF-8" #<= needed to pass the test
     str.eol = "LF"
-    expected = ["","","","a"," ","b","\n"].collect{|c| Uconv.euctou8(c)}
+    expected = ["","","","a"," ","b","\n"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, str.split_to_char)
   end
   def test_utf8_split_to_char_with_crlf()
-    str = Uconv.euctou8("ܸa b\r\n").extend CharString
+    str = NKF.nkf("-E -w", "ܸa b\r\n").extend CharString
     str.encoding = "UTF-8"#<= needed to pass the test
     str.eol = "CRLF"
-    expected = ["","","","a"," ","b","\r\n"].collect{|c| Uconv.euctou8(c)}
+    expected = ["","","","a"," ","b","\r\n"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, str.split_to_char)
   end
   def test_utf8_count_char()
-    str = Uconv.euctou8("ܸa b\r\n").extend CharString
+    str = NKF.nkf("-E -w", "ܸa b\r\n").extend CharString
     str.encoding = "UTF-8" #<= needed to pass the test
     str.eol = "CRLF"
     expected = 7
     assert_equal(expected, str.count_char)
   end
   def test_utf8_count_latin_graph_char()
-    str = Uconv.euctou8("ܸa b\r\n").extend CharString
+    str = NKF.nkf("-E -w", "ܸa b\r\n").extend CharString
     str.encoding = "UTF-8" #<= needed to pass the test
     str.eol = "CRLF"
     expected = 2
     assert_equal(expected, str.count_latin_graph_char)
   end
   def test_utf8_count_ja_graph_char()
-    str = Uconv.euctou8("ܸa b\r\n").extend CharString
+    str = NKF.nkf("-E -w", "ܸa b\r\n").extend CharString
     str.encoding = "UTF-8" #<= needed to pass the test
     str.eol = "CRLF"
     expected = 3
     assert_equal(expected, str.count_ja_graph_char)
   end
   def test_utf8_count_graph_char()
-    str = Uconv.euctou8("ܸa b\r\n").extend CharString
+    str = NKF.nkf("-E -w", "ܸa b\r\n").extend CharString
     str.encoding = "UTF-8" #<= needed to passs the test
     str.eol = "CRLF"
     expected = 5
     assert_equal(expected, str.count_graph_char)
   end
   def test_utf8_count_latin_blank_char()
-    str = Uconv.euctou8("ܸ\ta b\r\n").extend CharString
+    str = NKF.nkf("-E -w", "ܸ\ta b\r\n").extend CharString
     str.encoding = "UTF-8"
     str.eol = "CRLF"
     expected = 2
     assert_equal(expected, str.count_latin_blank_char)
   end
   def test_utf8_count_ja_blank_char()
-    str = Uconv.euctou8("ܡ\ta b\r\n").extend CharString
+    str = NKF.nkf("-E -w", "ܡ\ta b\r\n").extend CharString
     str.encoding = "UTF-8"
     str.eol = "CRLF"
     expected = 1
     assert_equal(expected, str.count_ja_blank_char)
   end
   def test_utf8_count_blank_char()
-    str = Uconv.euctou8("ܡ\ta b\r\n").extend CharString
+    str = NKF.nkf("-E -w", "ܡ\ta b\r\n").extend CharString
     str.encoding = "UTF-8"
     str.eol = "CRLF"
     expected = 3
     assert_equal(expected, str.count_blank_char)
   end
   def test_utf8_count_word()
-    str = Uconv.euctou8("ܡa b --\r\n").extend CharString
+    str = NKF.nkf("-E -w", "ܡa b --\r\n").extend CharString
     str.encoding = "UTF-8"
     str.eol = "CRLF"
     expected = 7 # "--" and "\r\n" are counted as word here (though not "valid")
     assert_equal(expected, str.count_word)
   end
   def test_utf8_count_ja_word()
-    str = Uconv.euctou8("ܡa b --\r\n").extend CharString
+    str = NKF.nkf("-E -w", "ܡa b --\r\n").extend CharString
     str.encoding = "UTF-8"
     str.eol = "CRLF"
     expected = 3
     assert_equal(expected, str.count_ja_word)
   end
   def test_utf8_count_latin_valid_word()
-    str = Uconv.euctou8("ܡa b --\r\n").extend CharString
+    str = NKF.nkf("-E -w", "ܡa b --\r\n").extend CharString
     str.encoding = "UTF-8"
     str.eol = "CRLF"
     expected = 2
     assert_equal(expected, str.count_latin_valid_word)
   end
   def test_utf8_count_ja_valid_word()
-    str = Uconv.euctou8("ܡa b --\r\n").extend CharString
+    str = NKF.nkf("-E -w", "ܡa b --\r\n").extend CharString
     str.encoding = "UTF-8"
     str.eol = "CRLF"
     expected = 2
     assert_equal(expected, str.count_ja_valid_word)
   end
   def test_utf8_count_valid_word()
-    str = Uconv.euctou8("ܡa b --\r\n").extend CharString
+    str = NKF.nkf("-E -w", "ܡa b --\r\n").extend CharString
     str.encoding = "UTF-8"
     str.eol = "CRLF"
     expected = 4
     assert_equal(expected, str.count_valid_word)
   end
   def test_utf8_count_line()
-    str = Uconv.euctou8("ܸ\r\n\r\n \r\n\r\nfoo\r\nbar").extend CharString
+    str = NKF.nkf("-E -w", "ܸ\r\n\r\n \r\n\r\nfoo\r\nbar").extend CharString
     str.encoding = "UTF-8"
     str.eol = "CRLF"
     expected = 6
     assert_equal(expected, str.count_line)
   end
   def test_utf8_count_graph_line()
-    str = Uconv.euctou8("ܸ\r\n\r\n \r\n\r\nfoo\r\nbar").extend CharString
+    str = NKF.nkf("-E -w", "ܸ\r\n\r\n \r\n\r\nfoo\r\nbar").extend CharString
     str.encoding = "UTF-8"
     str.eol = "CRLF"
     expected = 3
     assert_equal(expected, str.count_graph_line)
   end
   def test_utf8_count_empty_line()
-    str = Uconv.euctou8("ܸ\r\n\r\n \r\n\r\nfoo\r\nbar").extend CharString
+    str = NKF.nkf("-E -w", "ܸ\r\n\r\n \r\n\r\nfoo\r\nbar").extend CharString
     str.encoding = "UTF-8"
     str.eol = "CRLF"
     expected = 1
     assert_equal(expected, str.count_empty_line)
   end
   def test_utf8_count_blank_line()
-    str = Uconv.euctou8("ܸ\r\n\r\n \r\n\r\nfoo\r\nbar").extend CharString
+    str = NKF.nkf("-E -w", "ܸ\r\n\r\n \r\n\r\nfoo\r\nbar").extend CharString
     str.encoding = "UTF-8"
     str.eol = "CRLF"
     expected = 2
@@ -855,12 +855,18 @@ class TC_CharString < Test::Unit::TestCase
 
   # test module functions
 
+  def assert_guess_encoding(expected, str)
+    unless CharString.ruby_m17n?
+      assert_equal(expected, CharString.guess_encoding_using_pureruby(str))
+      assert_equal(expected, CharString.guess_encoding_using_iconv(str))
+    end
+    assert_equal(expected, CharString.guess_encoding(str))
+  end
+
   def test_guess_encoding_nil()
     str = nil
     expected = nil
-    assert_equal(expected, CharString.guess_encoding_using_pureruby(str))
-    assert_equal(expected, CharString.guess_encoding_using_iconv(str))
-    assert_equal(expected, CharString.guess_encoding(str))
+    assert_guess_encoding(expected, str)
   end
 #   def test_guess_encoding_binary()
 #     str = "\xFF\xFF"
@@ -868,89 +874,80 @@ class TC_CharString < Test::Unit::TestCase
 #     assert_equal(expected, CharString.guess_encoding(str))
 #   end
   def test_guess_encoding_unknown()
-    str = "\xff\xff\xff\xff"  # "\xDE\xAD\xBE\xEF"
-    expected = "UNKNOWN"
-    assert_equal(expected, CharString.guess_encoding_using_pureruby(str))
-    assert_equal(expected, CharString.guess_encoding_using_iconv(str))
-    assert_equal(expected, CharString.guess_encoding(str))
+    if CharString.ruby_m17n?
+      str = "".encode("BINARY") # cannot put invalid string literal
+      expected = "ASCII-8BIT"
+    else
+      str = "\xff\xff\xff\xff"  # "\xDE\xAD\xBE\xEF"
+      expected = "UNKNOWN"
+    end
+    assert_guess_encoding(expected, str)
   end
   def test_guess_encoding_ascii_1()
-    str = "ASCII string"
-    expected = "ASCII"
-    assert_equal(expected, CharString.guess_encoding_using_pureruby(str))
-    assert_equal(expected, CharString.guess_encoding_using_iconv(str))
-    assert_equal(expected, CharString.guess_encoding(str))
+    if CharString.ruby_m17n?
+      str = "ASCII string".encode("US-ASCII")
+      expected = "US-ASCII"
+    else
+      str = "ASCII string"
+      expected = "US-ASCII"
+    end
+    assert_guess_encoding(expected, str)
   end
   def test_guess_encoding_ascii_2()
-    str = "abc\ndef\n"
-    expected = "ASCII"
-    assert_equal(expected, CharString.guess_encoding_using_pureruby(str))
-    assert_equal(expected, CharString.guess_encoding_using_iconv(str))
-    assert_equal(expected, CharString.guess_encoding(str))
+    if CharString.ruby_m17n?
+      str = "abc\ndef\n".encode("US-ASCII")
+      expected = "US-ASCII"
+    else
+      str = "abc\ndef\n"
+      expected = "US-ASCII"
+    end
+    assert_guess_encoding(expected, str)
   end
 # CharString.guess_encoding mistakes JIS for ASCII sometimes, due to Iconv.
 #   def test_guess_encoding_jis_1()
 #     str = NKF.nkf("-j", "ȥʤȤҤ餬\n")
 #     expected = "JIS"
-#     assert_equal(expected, CharString.guess_encoding_using_pureruby(str))
-#     assert_equal(expected, CharString.guess_encoding_using_iconv(str))
-#     assert_equal(expected, CharString.guess_encoding(str))
+#     assert_guess_encoding(expected, str)
 #   end
 #   def test_guess_encoding_jis_2()
 #     str = NKF.nkf("-j", "ȥʤȤҤ餬ʤLatinʸȶ( )ȵ@\n" * 100)
 #     expected = "JIS"
-#     assert_equal(expected, CharString.guess_encoding_using_pureruby(str))
-#     assert_equal(expected, CharString.guess_encoding_using_iconv(str))
-#     assert_equal(expected, CharString.guess_encoding(str))
+#     assert_guess_encoding(expected, str)
 #   end
   def test_guess_encoding_eucjp_1()
     str = NKF.nkf("-e", "ܸLatinʸ")
     expected = "EUC-JP"
-    assert_equal(expected, CharString.guess_encoding_using_pureruby(str))
-    assert_equal(expected, CharString.guess_encoding_using_iconv(str))
-    assert_equal(expected, CharString.guess_encoding(str))
+    assert_guess_encoding(expected, str)
   end
   def test_guess_encoding_eucjp_2()
     str = NKF.nkf('-e', "ȥʤȤҤ餬ʤLatinʸȶ( )\n" * 10)
     expected = "EUC-JP"
-    assert_equal(expected, CharString.guess_encoding_using_pureruby(str))
-    assert_equal(expected, CharString.guess_encoding_using_iconv(str))
-    assert_equal(expected, CharString.guess_encoding(str))
+    assert_guess_encoding(expected, str)
   end
   def test_guess_encoding_eucjp_3()
     str = NKF.nkf('-e', "Фϡ̾ϤޤĤȤǤ\nRubyäΤϻǤRuby HackerǤ\n")
     expected = "EUC-JP"
-    assert_equal(expected, CharString.guess_encoding_using_pureruby(str))
-    assert_equal(expected, CharString.guess_encoding_using_iconv(str))
-    assert_equal(expected, CharString.guess_encoding(str))
+    assert_guess_encoding(expected, str)
   end
   def test_guess_encoding_sjis_1()
     str = NKF.nkf("-s", "ܸLatinʸ")
     expected = "Shift_JIS"
-    assert_equal(expected, CharString.guess_encoding_using_pureruby(str))
-    assert_equal(expected, CharString.guess_encoding_using_iconv(str))
-    assert_equal(expected, CharString.guess_encoding(str))
+    assert_guess_encoding(expected, str)
   end
   def test_guess_encoding_sjis_2()
     str = NKF.nkf('-s', "\nʤ\nҤ餬ʤ\nLatin")
     expected = "Shift_JIS"
-    assert_equal(expected, CharString.guess_encoding_using_pureruby(str))
-    assert_equal(expected, CharString.guess_encoding_using_iconv(str))
-    assert_equal(expected, CharString.guess_encoding(str))
+    assert_guess_encoding(expected, str)
   end
   def test_guess_encoding_utf8_1()
-    str = Uconv.euctou8("ܸLatinʸ")
+    str = NKF.nkf("-E -w", "ܸLatinʸ")
     expected = "UTF-8"
-    assert_equal(expected, CharString.guess_encoding_using_pureruby(str))
-    assert_equal(expected, CharString.guess_encoding_using_iconv(str))
-    assert_equal(expected, CharString.guess_encoding(str))
+    assert_guess_encoding(expected, str)
   end
   def test_guess_encoding_utf8_2()
-    str = Uconv.euctou8("\nˤۤؤ\n")
+    str = NKF.nkf("-E -w", "\nˤۤؤ\n")
     expected = "UTF-8"
-    assert_equal(expected, CharString.guess_encoding_using_pureruby(str))
-    assert_equal(expected, CharString.guess_encoding_using_iconv(str))
-    assert_equal(expected, CharString.guess_encoding(str))
+    assert_guess_encoding(expected, str)
   end
 
   def test_guess_eol_nil()
