@@ -1,8 +1,8 @@
 #!/usr/bin/ruby
+# -*- coding: euc-jp; -*-
 require 'test/unit'
 require 'docdiff/document'
 require 'nkf'
-require 'uconv'
 
 class TC_Document < Test::Unit::TestCase
 
@@ -12,19 +12,23 @@ class TC_Document < Test::Unit::TestCase
 
   def test_encoding()
     doc = Document.new("Foo bar.\nBaz quux.")
-    doc.encoding = 'ASCII'
+    doc.encoding = 'US-ASCII'
     doc.eol = 'LF'
-    expected = 'ASCII'
+    expected = 'US-ASCII'
     assert_equal(expected, doc.encoding)
   end
   def test_encoding_auto()
-    doc = Document.new("Foo bar.\nBaz quux.")
-    expected = 'ASCII'
+    doc = if CharString.ruby_m17n?
+            Document.new("Foo bar.\nBaz quux.".encode("US-ASCII"))
+          else
+            Document.new("Foo bar.\nBaz quux.")
+          end
+    expected = 'US-ASCII'
     assert_equal(expected, doc.encoding)
   end
   def test_eol()
     doc = Document.new("Foo bar.\nBaz quux.")
-    doc.encoding = 'ASCII'
+    doc.encoding = 'US-ASCII'
     doc.eol = 'LF'
     expected = 'LF'
     assert_equal(expected, doc.eol)
@@ -41,7 +45,7 @@ class TC_Document < Test::Unit::TestCase
   end
   def test_eol_char_lf()
     doc = Document.new("Foo bar.\nBaz quux.")
-#    doc.encoding = "ASCII"
+#    doc.encoding = "US-ASCII"
 #    doc.eol = "LF"
     expected = "\n"
     assert_equal(expected, doc.eol_char)
@@ -482,132 +486,132 @@ class TC_Document < Test::Unit::TestCase
 
   # test UTF8 module
   def test_utf8_split_to_word()
-    doc = Document.new(Uconv.euctou8("ܸʸfoo bar"))
-    expected = ["ܸ", "ʸ", "foo ", "bar"].collect{|c| Uconv.euctou8(c)}
+    doc = Document.new(NKF.nkf("-E -w", "ܸʸfoo bar"))
+    expected = ["ܸ", "ʸ", "foo ", "bar"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, doc.split_to_word)
   end
   def test_utf8_split_to_word_kanhira()
-    doc = Document.new(Uconv.euctou8("ܸʸ"))
-    expected = ["ܸ", "ʸ"].collect{|c| Uconv.euctou8(c)}
+    doc = Document.new(NKF.nkf("-E -w", "ܸʸ"))
+    expected = ["ܸ", "ʸ"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, doc.split_to_word)
   end
   def test_utf8_split_to_word_katahira()
-    doc = Document.new(Uconv.euctou8("ʤʸ"))
-    expected = ["ʤ", "ʸ"].collect{|c| Uconv.euctou8(c)}
+    doc = Document.new(NKF.nkf("-E -w", "ʤʸ"))
+    expected = ["ʤ", "ʸ"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, doc.split_to_word)
   end
   def test_utf8_split_to_word_kataonbiki()
-    doc = Document.new(Uconv.euctou8("ӡλ"))
-    expected = ["ӡ", ""].collect{|c| Uconv.euctou8(c)}
+    doc = Document.new(NKF.nkf("-E -w", "ӡλ"))
+    expected = ["ӡ", ""].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, doc.split_to_word)
   end
   def test_utf8_split_to_word_hiraonbiki()
-    doc = Document.new(Uconv.euctou8("ӡ"))
-    expected = ["", "ӡ"].collect{|c| Uconv.euctou8(c)}
+    doc = Document.new(NKF.nkf("-E -w", "ӡ"))
+    expected = ["", "ӡ"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, doc.split_to_word)
   end
   def test_utf8_split_to_word_latinmix()
-    doc = Document.new(Uconv.euctou8("ܸLatinʸ"))
-    expected = ["ܸ", "Latin", "", "ʸ"].collect{|c| Uconv.euctou8(c)}
+    doc = Document.new(NKF.nkf("-E -w", "ܸLatinʸ"))
+    expected = ["ܸ", "Latin", "", "ʸ"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, doc.split_to_word)
   end
   def test_utf8_split_to_char()
-    doc = Document.new(Uconv.euctou8("ܸa b"), "UTF-8")
-    expected = ["", "", "", "a", " ", "b"].collect{|c| Uconv.euctou8(c)}
+    doc = Document.new(NKF.nkf("-E -w", "ܸa b"), "UTF-8")
+    expected = ["", "", "", "a", " ", "b"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, doc.split_to_char)
   end
   def test_utf8_split_to_char_with_cr()
-    doc = Document.new(Uconv.euctou8("ܸa b\r"), "UTF-8")
-    expected = ["","","","a"," ","b","\r"].collect{|c| Uconv.euctou8(c)}
+    doc = Document.new(NKF.nkf("-E -w", "ܸa b\r"), "UTF-8")
+    expected = ["","","","a"," ","b","\r"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, doc.split_to_char)
   end
   def test_utf8_split_to_char_with_lf()
-    doc = Document.new(Uconv.euctou8("ܸa b\n"), "UTF-8")
-    expected = ["","","","a"," ","b","\n"].collect{|c| Uconv.euctou8(c)}
+    doc = Document.new(NKF.nkf("-E -w", "ܸa b\n"), "UTF-8")
+    expected = ["","","","a"," ","b","\n"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, doc.split_to_char)
   end
   def test_utf8_split_to_char_with_crlf()
-    doc = Document.new(Uconv.euctou8("ܸa b\r\n"), "UTF-8")
-    expected = ["","","","a"," ","b","\r\n"].collect{|c| Uconv.euctou8(c)}
+    doc = Document.new(NKF.nkf("-E -w", "ܸa b\r\n"), "UTF-8")
+    expected = ["","","","a"," ","b","\r\n"].collect{|c| NKF.nkf("-E -w", c)}
     assert_equal(expected, doc.split_to_char)
   end
   def test_utf8_count_char()
-    doc = Document.new(Uconv.euctou8("ܸa b\r\n"), "UTF-8")
+    doc = Document.new(NKF.nkf("-E -w", "ܸa b\r\n"), "UTF-8")
     expected = 7
     assert_equal(expected, doc.count_char)
   end
   def test_utf8_count_latin_graph_char()
-    doc = Document.new(Uconv.euctou8("ܸa b\r\n"), "UTF-8")
+    doc = Document.new(NKF.nkf("-E -w", "ܸa b\r\n"), "UTF-8")
     expected = 2
     assert_equal(expected, doc.count_latin_graph_char)
   end
   def test_utf8_count_ja_graph_char()
-    doc = Document.new(Uconv.euctou8("ܸa b\r\n"), "UTF-8")
+    doc = Document.new(NKF.nkf("-E -w", "ܸa b\r\n"), "UTF-8")
     expected = 3
     assert_equal(expected, doc.count_ja_graph_char)
   end
   def test_utf8_count_graph_char()
-    doc = Document.new(Uconv.euctou8("ܸa b\r\n"), "UTF-8")
+    doc = Document.new(NKF.nkf("-E -w", "ܸa b\r\n"), "UTF-8")
     expected = 5
     assert_equal(expected, doc.count_graph_char)
   end
   def test_utf8_count_latin_blank_char()
-    doc = Document.new(Uconv.euctou8("ܸ\ta b\r\n"))
+    doc = Document.new(NKF.nkf("-E -w", "ܸ\ta b\r\n"))
     expected = 2
     assert_equal(expected, doc.count_latin_blank_char)
   end
   def test_utf8_count_ja_blank_char()
-    doc = Document.new(Uconv.euctou8("ܡ\ta b\r\n"))
+    doc = Document.new(NKF.nkf("-E -w", "ܡ\ta b\r\n"))
     expected = 1
     assert_equal(expected, doc.count_ja_blank_char)
   end
   def test_utf8_count_blank_char()
-    doc = Document.new(Uconv.euctou8("ܡ\ta b\r\n"))
+    doc = Document.new(NKF.nkf("-E -w", "ܡ\ta b\r\n"))
     expected = 3
     assert_equal(expected, doc.count_blank_char)
   end
   def test_utf8_count_word()
-    doc = Document.new(Uconv.euctou8("ܡa b --\r\n"))
+    doc = Document.new(NKF.nkf("-E -w", "ܡa b --\r\n"))
     expected = 7 # "--" and "\r\n" are counted as word here (though not "valid")
     assert_equal(expected, doc.count_word)
   end
   def test_utf8_count_ja_word()
-    doc = Document.new(Uconv.euctou8("ܡa b --\r\n"))
+    doc = Document.new(NKF.nkf("-E -w", "ܡa b --\r\n"))
     expected = 3
     assert_equal(expected, doc.count_ja_word)
   end
   def test_utf8_count_latin_valid_word()
-    doc = Document.new(Uconv.euctou8("ܡa b --\r\n"))
+    doc = Document.new(NKF.nkf("-E -w", "ܡa b --\r\n"))
     expected = 2
     assert_equal(expected, doc.count_latin_valid_word)
   end
   def test_utf8_count_ja_valid_word()
-    doc = Document.new(Uconv.euctou8("ܡa b --\r\n"))
+    doc = Document.new(NKF.nkf("-E -w", "ܡa b --\r\n"))
     expected = 2
     assert_equal(expected, doc.count_ja_valid_word)
   end
   def test_utf8_count_valid_word()
-    doc = Document.new(Uconv.euctou8("ܡa b --\r\n"))
+    doc = Document.new(NKF.nkf("-E -w", "ܡa b --\r\n"))
     expected = 4
     assert_equal(expected, doc.count_valid_word)
   end
   def test_utf8_count_line()
-    doc = Document.new(Uconv.euctou8("ܸ\r\n\r\n \r\n\r\nfoo\r\nbar"))
+    doc = Document.new(NKF.nkf("-E -w", "ܸ\r\n\r\n \r\n\r\nfoo\r\nbar"))
     expected = 6
     assert_equal(expected, doc.count_line)
   end
   def test_utf8_count_graph_line()
-    doc = Document.new(Uconv.euctou8("ܸ\r\n\r\n \r\n\r\nfoo\r\nbar"))
+    doc = Document.new(NKF.nkf("-E -w", "ܸ\r\n\r\n \r\n\r\nfoo\r\nbar"))
     expected = 3
     assert_equal(expected, doc.count_graph_line)
   end
   def test_utf8_count_empty_line()
-    doc = Document.new(Uconv.euctou8("ܸ\r\n\r\n \r\n\r\nfoo\r\nbar"))
+    doc = Document.new(NKF.nkf("-E -w", "ܸ\r\n\r\n \r\n\r\nfoo\r\nbar"))
     expected = 1
     assert_equal(expected, doc.count_empty_line)
   end
   def test_utf8_count_blank_line()
-    doc = Document.new(Uconv.euctou8("ܸ\r\n\r\n \r\n\r\nfoo\r\nbar"))
+    doc = Document.new(NKF.nkf("-E -w", "ܸ\r\n\r\n \r\n\r\nfoo\r\nbar"))
     expected = 2
     assert_equal(expected, doc.count_blank_line)
   end
