@@ -1,9 +1,9 @@
 #!/usr/bin/ruby
+# -*- coding: euc-jp; -*-
 require 'test/unit'
 require 'docdiff/view'
 require 'docdiff/difference'
 require 'nkf'
-require 'uconv'
 
 class TC_View < Test::Unit::TestCase
 
@@ -35,7 +35,7 @@ class TC_View < Test::Unit::TestCase
     array2 = ["b", "c", "c"]
     difference = Difference.new(array1, array2)
     expected =   ["A\r", "\r", "A\n\nA\r", "\n\r", "\nA\n\r", "\n\r", "A"]
-    actual = View.new(difference, "ASCII", "CR").source_lines
+    actual = View.new(difference, "US-ASCII", "CR").source_lines
     assert_equal(expected, actual)
   end
   def test_source_lines_cr2()
@@ -43,7 +43,7 @@ class TC_View < Test::Unit::TestCase
     array2 = ["b", "c", "c"]
     difference = Difference.new(array1, array2)
     expected =   ["A\r", "\r", "A\n\nA\r", "\n\r", "\nA\n\r", "\n\r"]
-    actual = View.new(difference, "ASCII", "CR").source_lines
+    actual = View.new(difference, "US-ASCII", "CR").source_lines
     assert_equal(expected, actual)
   end
   def test_source_lines_lf()
@@ -51,7 +51,7 @@ class TC_View < Test::Unit::TestCase
     array2 = ["b", "c", "c"]
     difference = Difference.new(array1, array2)
     expected =   ["A\r\rA\n", "\n", "A\r\n", "\r\n", "A\n", "\r\n", "\rA"]
-    actual = View.new(difference, "ASCII", "LF").source_lines
+    actual = View.new(difference, "US-ASCII", "LF").source_lines
     assert_equal(expected, actual)
   end
   def test_source_lines_lf2()
@@ -59,7 +59,7 @@ class TC_View < Test::Unit::TestCase
     array2 = ["b", "c", "c"]
     difference = Difference.new(array1, array2)
     expected =   ["A\r\rA\n", "\n", "A\r\n", "\r\n", "A\n", "\r\n", "\r"]
-    actual = View.new(difference, "ASCII", "LF").source_lines
+    actual = View.new(difference, "US-ASCII", "LF").source_lines
     assert_equal(expected, actual)
   end
   def test_source_lines_crlf()
@@ -67,7 +67,7 @@ class TC_View < Test::Unit::TestCase
     array2 = ["b", "c", "c"]
     difference = Difference.new(array1, array2)
     expected =   ["A\r\rA\n\nA\r\n", "\r\n", "A\n\r\n", "\rA"]
-    actual = View.new(difference, "ASCII", "CRLF").source_lines
+    actual = View.new(difference, "US-ASCII", "CRLF").source_lines
     assert_equal(expected, actual)
   end
   def test_source_lines_crlf2()
@@ -75,7 +75,7 @@ class TC_View < Test::Unit::TestCase
     array2 = ["b", "c", "c"]
     difference = Difference.new(array1, array2)
     expected =   ["A\r\rA\n\nA\r\n", "\r\n", "A\n\r\n", "\r"]
-    actual = View.new(difference, "ASCII", "CRLF").source_lines
+    actual = View.new(difference, "US-ASCII", "CRLF").source_lines
     assert_equal(expected, actual)
   end
   def test_source_lines_noeol()
@@ -83,7 +83,7 @@ class TC_View < Test::Unit::TestCase
     array2 = ["b", "c", "c"]
     difference = Difference.new(array1, array2)
     expected =   ["abc"]
-    actual = View.new(difference, "ASCII", nil).source_lines
+    actual = View.new(difference, "US-ASCII", nil).source_lines
     assert_equal(expected, actual)
   end
   def test_target_lines_cr()
@@ -91,7 +91,7 @@ class TC_View < Test::Unit::TestCase
     array2 = "A\r\rA\n\nA\r\n\r\nA\n\r\n\rA".split(//)
     difference = Difference.new(array1, array2)
     expected =   ["A\r", "\r", "A\n\nA\r", "\n\r", "\nA\n\r", "\n\r", "A"]
-    actual = View.new(difference, "ASCII", "CR").target_lines
+    actual = View.new(difference, "US-ASCII", "CR").target_lines
     assert_equal(expected, actual)
   end
   def test_target_lines_cr2()
@@ -99,7 +99,7 @@ class TC_View < Test::Unit::TestCase
     array2 = "A\r\rA\n\nA\r\n\r\nA\n\r\n\r".split(//)
     difference = Difference.new(array1, array2)
     expected =   ["A\r", "\r", "A\n\nA\r", "\n\r", "\nA\n\r", "\n\r"]
-    actual = View.new(difference, "ASCII", "CR").target_lines
+    actual = View.new(difference, "US-ASCII", "CR").target_lines
     assert_equal(expected, actual)
   end
   def test_target_lines_lf()
@@ -107,7 +107,7 @@ class TC_View < Test::Unit::TestCase
     array2 = "A\r\rA\n\nA\r\n\r\nA\n\r\n\rA".split(//)
     difference = Difference.new(array1, array2)
     expected =   ["A\r\rA\n", "\n", "A\r\n", "\r\n", "A\n", "\r\n", "\rA"]
-    actual = View.new(difference, "ASCII", "LF").target_lines
+    actual = View.new(difference, "US-ASCII", "LF").target_lines
     assert_equal(expected, actual)
   end
   def test_target_lines_lf2()
@@ -115,7 +115,7 @@ class TC_View < Test::Unit::TestCase
     array2 = "A\r\rA\n\nA\r\n\r\nA\n\r\n\r".split(//)
     difference = Difference.new(array1, array2)
     expected =   ["A\r\rA\n", "\n", "A\r\n", "\r\n", "A\n", "\r\n", "\r"]
-    actual = View.new(difference, "ASCII", "LF").target_lines
+    actual = View.new(difference, "US-ASCII", "LF").target_lines
     assert_equal(expected, actual)
   end
   def test_target_lines_crlf()
@@ -123,7 +123,7 @@ class TC_View < Test::Unit::TestCase
     array2 = "A\r\rA\n\nA\r\n\r\nA\n\r\n\rA".split(//)
     difference = Difference.new(array1, array2)
     expected = ["A\r\rA\n\nA\r\n", "\r\n", "A\n\r\n", "\rA"]
-    actual = View.new(difference, "ASCII", "CRLF").target_lines
+    actual = View.new(difference, "US-ASCII", "CRLF").target_lines
     assert_equal(expected, actual)
   end
   def test_target_lines_crlf2()
@@ -131,7 +131,7 @@ class TC_View < Test::Unit::TestCase
     array2 = "A\r\rA\n\nA\r\n\r\nA\n\r\n\r".split(//)
     difference = Difference.new(array1, array2)
     expected = ["A\r\rA\n\nA\r\n", "\r\n", "A\n\r\n", "\r"]
-    actual = View.new(difference, "ASCII", "CRLF").target_lines
+    actual = View.new(difference, "US-ASCII", "CRLF").target_lines
     assert_equal(expected, actual)
   end
   def test_target_lines_noeol()
@@ -139,7 +139,7 @@ class TC_View < Test::Unit::TestCase
     array2 = ["b", "c", "c"]
     difference = Difference.new(array1, array2)
     expected =   ["bcc"]
-    actual = View.new(difference, "ASCII", nil).target_lines
+    actual = View.new(difference, "US-ASCII", nil).target_lines
     assert_equal(expected, actual)
   end
 
@@ -151,7 +151,7 @@ class TC_View < Test::Unit::TestCase
                   "b",
                   "\033[7;1;34mc\033[0m",
                   "c"]
-    assert_equal(expected, View.new(difference, "ASCII", nil).to_tty(nil, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", nil).to_tty(nil, false))
   end
   def test_to_tty_change_ascii()
     array1 = ['a', 'b', 'c']
@@ -160,7 +160,7 @@ class TC_View < Test::Unit::TestCase
     expected =   ["a",
                   "\033[7;4;33mb\033[0m\033[7;1;32mx\033[0m",
                   "c"]
-    assert_equal(expected, View.new(difference, "ASCII", nil).to_tty(nil, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", nil).to_tty(nil, false))
   end
   def test_to_tty_del_add_ja()
     array1 = ['', '', '']
@@ -174,9 +174,9 @@ class TC_View < Test::Unit::TestCase
                  View.new(Difference.new(array1.collect{|i|NKF.nkf("-s",i)},
                                          array2.collect{|i|NKF.nkf("-s",i)}),
                           "Shift_JIS", nil).to_tty(nil, false))
-    assert_equal(expected.collect{|i|Uconv.euctou8(i)},
-                 View.new(Difference.new(array1.collect{|i|Uconv.euctou8(i)},
-                                         array2.collect{|i|Uconv.euctou8(i)}),
+    assert_equal(expected.collect{|i|NKF.nkf("-E -w", i)},
+                 View.new(Difference.new(array1.collect{|i|NKF.nkf("-E -w", i)},
+                                         array2.collect{|i|NKF.nkf("-E -w", i)}),
                           "UTF-8", nil).to_tty(nil, false))
   end
   def test_to_tty_change_ja()
@@ -190,9 +190,9 @@ class TC_View < Test::Unit::TestCase
                  View.new(Difference.new(array1.collect{|i|NKF.nkf("-s",i)},
                                          array2.collect{|i|NKF.nkf("-s",i)}),
                           "Shift_JIS", nil).to_tty(nil, false))
-    assert_equal(expected.collect{|i|Uconv.euctou8(i)},
-                 View.new(Difference.new(array1.collect{|i|Uconv.euctou8(i)},
-                                         array2.collect{|i|Uconv.euctou8(i)}),
+    assert_equal(expected.collect{|i|NKF.nkf("-E -w", i)},
+                 View.new(Difference.new(array1.collect{|i|NKF.nkf("-E -w", i)},
+                                         array2.collect{|i|NKF.nkf("-E -w", i)}),
                           "UTF-8", nil).to_tty(nil, false))
   end
   def test_to_tty_digest()
@@ -202,7 +202,7 @@ class TC_View < Test::Unit::TestCase
                   "1-2,(1)\n\033[7;4;31ma\nb\033[0mcd\n----\n",
                   "(2),1-2\ncd\033[7;1;34mX\nY\033[0me\n\n----\n",
                   "3,3\ne\n\033[7;4;33mf\033[0m\033[7;1;32mF\033[0m\n\n----\n"]
-    assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").to_tty_digest(nil, false))
+    assert_equal(expected, View.new(Difference.new(array1, array2), "US-ASCII", "LF").to_tty_digest(nil, false))
   end
   def test_to_tty_digest_multi()
     array1 = ["a", "\n", "b", "c", "d", "e", "\n", "f", "\n"]
@@ -211,7 +211,7 @@ class TC_View < Test::Unit::TestCase
                   "1-2,(1)\na\nbcd\n\033[7;4;31ma\nb\033[0mcd\n----\n",
                   "(2),1-2\ncde\n\ncd\033[7;1;34mX\nY\033[0me\n\n----\n",
                   "3,3\ne\n\033[7;4;33mf\033[0m\n\ne\n\033[7;1;32mF\033[0m\n\n----\n"]
-    assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").to_tty_digest({:display=>'multi'}, false))
+    assert_equal(expected, View.new(Difference.new(array1, array2), "US-ASCII", "LF").to_tty_digest({:display=>'multi'}, false))
   end
 
   def test_to_html_cr_ascii()
@@ -219,28 +219,28 @@ class TC_View < Test::Unit::TestCase
     array2 = ['a', "\r"]
     difference = Difference.new(array1, array2)
     expected =   ["<span class=\"common\">a<br />\r</span>"]
-    assert_equal(expected, View.new(difference, "ASCII", "CR").to_html(nil, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", "CR").to_html(nil, false))
   end
   def test_to_html_lf_ascii()
     array1 = ['a', "\n"]
     array2 = ['a', "\n"]
     difference = Difference.new(array1, array2)
     expected =   ["<span class=\"common\">a<br />\n</span>"]
-    assert_equal(expected, View.new(difference, "ASCII", "LF").to_html(nil, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", "LF").to_html(nil, false))
   end
   def test_to_html_crlf_ascii()
     array1 = ['a', "\r\n"]
     array2 = ['a', "\r\n"]
     difference = Difference.new(array1, array2)
     expected =   ["<span class=\"common\">a<br />\r\n</span>"]
-    assert_equal(expected, View.new(difference, "ASCII", "CRLF").to_html(nil, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", "CRLF").to_html(nil, false))
   end
   def test_to_html_escaping_ascii()
     array1 = ['<>&   ']
     array2 = ['<>&   ']
     difference = Difference.new(array1, array2)
     expected =   ["<span class=\"common\">&lt;&gt;&amp;&nbsp;&nbsp; </span>"]
-    assert_equal(expected, View.new(difference, "ASCII", nil).to_html(nil, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", nil).to_html(nil, false))
   end
   def test_to_html_digest()
     array1 = ["a", "\n", "b", "c", "d", "e", "\n", "f", "\n"]
@@ -250,7 +250,7 @@ class TC_View < Test::Unit::TestCase
                   "<li class=\"entry\"><p class=\"position\">(2),1-2</p><blockquote class=\"body\"><p class=\"body\">cd<span class=\"add\"><ins>X<br />\nY</ins></span>e<br />\n</p></blockquote></li>\n",
                   "<li class=\"entry\"><p class=\"position\">3,3</p><blockquote class=\"body\"><p class=\"body\">e<br />\n<span class=\"before-change\"><del>f</del></span><span class=\"after-change\"><ins>F</ins></span><br />\n</p></blockquote></li>\n",
                   "</ul>"]
-    assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").to_html_digest(nil,false))
+    assert_equal(expected, View.new(Difference.new(array1, array2), "US-ASCII", "LF").to_html_digest(nil,false))
   end
   def test_to_html_digest_multi()
     array1 = ["a", "\n", "b", "c", "d", "e", "\n", "f", "\n"]
@@ -260,7 +260,7 @@ class TC_View < Test::Unit::TestCase
                   "<li class=\"entry\"><p class=\"position\">(2),1-2</p><blockquote class=\"body\"><p class=\"body\">cde<br />\n</p><p class=\"body\">cd<span class=\"add\"><ins>X<br />\nY</ins></span>e<br />\n</p></blockquote></li>\n",
                   "<li class=\"entry\"><p class=\"position\">3,3</p><blockquote class=\"body\"><p class=\"body\">e<br />\n<span class=\"before-change\"><del>f</del></span><br />\n</p><p class=\"body\">e<br />\n<span class=\"after-change\"><ins>F</ins></span><br />\n</p></blockquote></li>\n",
                   "</ul>"]
-    assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").to_html_digest({:display=>'multi'},false))
+    assert_equal(expected, View.new(Difference.new(array1, array2), "US-ASCII", "LF").to_html_digest({:display=>'multi'},false))
   end
 
   def test_to_html_del_add_ascii()
@@ -271,7 +271,7 @@ class TC_View < Test::Unit::TestCase
                   '<span class="common">b</span>',
                   '<span class="add"><ins>c</ins></span>',
                   '<span class="common">c</span>']
-    assert_equal(expected, View.new(difference, "ASCII", nil).to_html(nil, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", nil).to_html(nil, false))
   end
   def test_to_html_change_ascii()
     array1 = ['a', 'b', 'c']
@@ -280,7 +280,7 @@ class TC_View < Test::Unit::TestCase
     expected =   ['<span class="common">a</span>',
                   '<span class="before-change"><del>b</del></span><span class="after-change"><ins>x</ins></span>',
                   '<span class="common">c</span>']
-    assert_equal(expected, View.new(difference, "ASCII", nil).to_html(nil, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", nil).to_html(nil, false))
   end
   def test_to_html_del_add_ja()
     array1 = ['', '', '']
@@ -294,9 +294,9 @@ class TC_View < Test::Unit::TestCase
                  View.new(Difference.new(array1.collect{|i|NKF.nkf("-s",i)},
                                          array2.collect{|i|NKF.nkf("-s",i)}),
                           "Shift_JIS", nil).to_html(nil, false))
-    assert_equal(expected.collect{|i|Uconv.euctou8(i)},
-                 View.new(Difference.new(array1.collect{|i|Uconv.euctou8(i)},
-                                         array2.collect{|i|Uconv.euctou8(i)}),
+    assert_equal(expected.collect{|i|NKF.nkf("-E -w", i)},
+                 View.new(Difference.new(array1.collect{|i|NKF.nkf("-E -w", i)},
+                                         array2.collect{|i|NKF.nkf("-E -w", i)}),
                           "UTF-8", nil).to_html(nil, false))
   end
   def test_to_html_change_ja()
@@ -310,9 +310,9 @@ class TC_View < Test::Unit::TestCase
                  View.new(Difference.new(array1.collect{|i|NKF.nkf("-s",i)},
                                          array2.collect{|i|NKF.nkf("-s",i)}),
                           "Shift_JIS", nil).to_html(nil, false))
-    assert_equal(expected.collect{|i|Uconv.euctou8(i)},
-                 View.new(Difference.new(array1.collect{|i|Uconv.euctou8(i)},
-                                         array2.collect{|i|Uconv.euctou8(i)}),
+    assert_equal(expected.collect{|i|NKF.nkf("-E -w", i)},
+                 View.new(Difference.new(array1.collect{|i|NKF.nkf("-E -w", i)},
+                                         array2.collect{|i|NKF.nkf("-E -w", i)}),
                           "UTF-8", nil).to_html(nil, false))
   end
 
@@ -324,7 +324,7 @@ class TC_View < Test::Unit::TestCase
                   'b',
                   '[/c]',
                   'c']
-    assert_equal(expected, View.new(difference, "ASCII", nil).to_manued(nil, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", nil).to_manued(nil, false))
   end
   def test_to_manued_change_ascii()
     array1 = ['a', 'b', 'c']
@@ -333,7 +333,7 @@ class TC_View < Test::Unit::TestCase
     expected =   ['a',
                   '[b/x]',
                   'c']
-    assert_equal(expected, View.new(difference, "ASCII", nil).to_manued(nil, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", nil).to_manued(nil, false))
   end
   def test_to_manued_del_add_ja()
     array1 = ['', '', '']
@@ -347,9 +347,9 @@ class TC_View < Test::Unit::TestCase
                  View.new(Difference.new(array1.collect{|i|NKF.nkf("-s",i)},
                                          array2.collect{|i|NKF.nkf("-s",i)}),
                           "Shift_JIS", nil).to_manued(nil, false))
-    assert_equal(expected.collect{|i|Uconv.euctou8(i)},
-                 View.new(Difference.new(array1.collect{|i|Uconv.euctou8(i)},
-                                         array2.collect{|i|Uconv.euctou8(i)}),
+    assert_equal(expected.collect{|i|NKF.nkf("-E -w", i)},
+                 View.new(Difference.new(array1.collect{|i|NKF.nkf("-E -w", i)},
+                                         array2.collect{|i|NKF.nkf("-E -w", i)}),
                           "UTF-8", nil).to_manued(nil, false))
   end
   def test_to_manued_change_ja()
@@ -363,9 +363,9 @@ class TC_View < Test::Unit::TestCase
                  View.new(Difference.new(array1.collect{|i|NKF.nkf("-s",i)},
                                          array2.collect{|i|NKF.nkf("-s",i)}),
                           "Shift_JIS", nil).to_manued(nil, false))
-    assert_equal(expected.collect{|i|Uconv.euctou8(i)},
-                 View.new(Difference.new(array1.collect{|i|Uconv.euctou8(i)},
-                                         array2.collect{|i|Uconv.euctou8(i)}),
+    assert_equal(expected.collect{|i|NKF.nkf("-E -w", i)},
+                 View.new(Difference.new(array1.collect{|i|NKF.nkf("-E -w", i)},
+                                         array2.collect{|i|NKF.nkf("-E -w", i)}),
                           "UTF-8", nil).to_manued(nil, false))
   end
   def test_to_manued_escaping_ascii()
@@ -373,7 +373,7 @@ class TC_View < Test::Unit::TestCase
     array2 = ['a', '[/;]~', 'b']
     difference = Difference.new(array1, array2)
     expected =   ["a~[/;]~~b", "[~[~/~;~]~~/]"]
-    assert_equal(expected, View.new(difference, "ASCII", nil).to_manued(nil, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", nil).to_manued(nil, false))
   end
   def test_to_manued_digest()
     array1 = ["a", "\n", "b", "c", "d", "e", "\n", "f", "\n"]
@@ -382,7 +382,7 @@ class TC_View < Test::Unit::TestCase
                   "1-2,(1)\n[a\nb/]cd\n----\n",
                   "(2),1-2\ncd[/X\nY]e\n\n----\n",
                   "3,3\ne\n[f/F]\n\n----\n"]
-    assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").to_manued_digest(nil,false))
+    assert_equal(expected, View.new(Difference.new(array1, array2), "US-ASCII", "LF").to_manued_digest(nil,false))
   end
   def test_to_manued_digest_multi()
     array1 = ["a", "\n", "b", "c", "d", "e", "\n", "f", "\n"]
@@ -391,7 +391,7 @@ class TC_View < Test::Unit::TestCase
                   "1-2,(1)\na\nbcd\n[a\nb/]cd\n----\n",
                   "(2),1-2\ncde\n\ncd[/X\nY]e\n\n----\n",
                   "3,3\ne\n[f/]\n\ne\n[/F]\n\n----\n"]
-    assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").to_manued_digest({:display=>'multi'},false))
+    assert_equal(expected, View.new(Difference.new(array1, array2), "US-ASCII", "LF").to_manued_digest({:display=>'multi'},false))
   end
 
   def test_to_wdiff_del_add_ascii()
@@ -402,7 +402,7 @@ class TC_View < Test::Unit::TestCase
                   'b',
                   '{+c+}',
                   'c']
-    assert_equal(expected, View.new(difference, "ASCII", nil).to_wdiff(nil, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", nil).to_wdiff(nil, false))
   end
   def test_to_wdiff_change_ascii()
     array1 = ['a', 'b', 'c']
@@ -411,7 +411,7 @@ class TC_View < Test::Unit::TestCase
     expected =   ['a',
                   '[-b-]{+x+}',
                   'c']
-    assert_equal(expected, View.new(difference, "ASCII", nil).to_wdiff(nil, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", nil).to_wdiff(nil, false))
   end
   def test_to_wdiff_del_add_ja()
     array1 = ['', '', '']
@@ -425,9 +425,9 @@ class TC_View < Test::Unit::TestCase
                  View.new(Difference.new(array1.collect{|i|NKF.nkf("-s",i)},
                                          array2.collect{|i|NKF.nkf("-s",i)}),
                           "Shift_JIS", nil).to_wdiff(nil, false))
-    assert_equal(expected.collect{|i|Uconv.euctou8(i)},
-                 View.new(Difference.new(array1.collect{|i|Uconv.euctou8(i)},
-                                         array2.collect{|i|Uconv.euctou8(i)}),
+    assert_equal(expected.collect{|i|NKF.nkf("-E -w", i)},
+                 View.new(Difference.new(array1.collect{|i|NKF.nkf("-E -w", i)},
+                                         array2.collect{|i|NKF.nkf("-E -w", i)}),
                           "UTF-8", nil).to_wdiff(nil, false))
   end
   def test_to_wdiff_change_ja()
@@ -441,9 +441,9 @@ class TC_View < Test::Unit::TestCase
                  View.new(Difference.new(array1.collect{|i|NKF.nkf("-s",i)},
                                          array2.collect{|i|NKF.nkf("-s",i)}),
                           "Shift_JIS", nil).to_wdiff(nil, false))
-    assert_equal(expected.collect{|i|Uconv.euctou8(i)},
-                 View.new(Difference.new(array1.collect{|i|Uconv.euctou8(i)},
-                                         array2.collect{|i|Uconv.euctou8(i)}),
+    assert_equal(expected.collect{|i|NKF.nkf("-E -w", i)},
+                 View.new(Difference.new(array1.collect{|i|NKF.nkf("-E -w", i)},
+                                         array2.collect{|i|NKF.nkf("-E -w", i)}),
                           "UTF-8", nil).to_wdiff(nil, false))
   end
   def test_to_wdiff_digest()
@@ -453,7 +453,7 @@ class TC_View < Test::Unit::TestCase
                 "1-2,(1)\n[-a\nb-]cd\n----\n",
                 "(2),1-2\ncd{+X\nY+}e\n\n----\n",
                 "3,3\ne\n[-f-]{+F+}\n\n----\n"]
-    assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").to_wdiff_digest(nil,false))
+    assert_equal(expected, View.new(Difference.new(array1, array2), "US-ASCII", "LF").to_wdiff_digest(nil,false))
   end
   def test_to_wdiff_digest_multi()
     array1 = ["a", "\n", "b", "c", "d", "e", "\n", "f", "\n"]
@@ -462,7 +462,7 @@ class TC_View < Test::Unit::TestCase
                 "1-2,(1)\na\nbcd\n[-a\nb-]cd\n----\n",
                 "(2),1-2\ncde\n\ncd{+X\nY+}e\n\n----\n",
                 "3,3\ne\n[-f-]\n\ne\n{+F+}\n\n----\n"]
-    assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").to_wdiff_digest({:display => 'multi'}, false))
+    assert_equal(expected, View.new(Difference.new(array1, array2), "US-ASCII", "LF").to_wdiff_digest({:display => 'multi'}, false))
   end
 
   def test_to_user_del_add_en()
@@ -483,7 +483,7 @@ class TC_View < Test::Unit::TestCase
                   '<=>b</=>',
                   '<+>c</+>',
                   '<=>c</=>']
-    assert_equal(expected, View.new(difference, "ASCII", nil).to_user(user_tags, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", nil).to_user(user_tags, false))
   end
   def test_to_user_change_en()
     array1 = ['a', 'b', 'c']
@@ -502,7 +502,7 @@ class TC_View < Test::Unit::TestCase
     expected =   ['<=>a</=>',
                   '<!->b</!-><!+>x</!+>',
                   '<=>c</=>']
-    assert_equal(expected, View.new(difference, "ASCII", nil).to_user(user_tags, false))
+    assert_equal(expected, View.new(difference, "US-ASCII", nil).to_user(user_tags, false))
   end
   def test_to_user_digest()
     array1 = ["a", "\n", "b", "c", "d", "e", "\n", "f", "\n"]
@@ -520,7 +520,7 @@ class TC_View < Test::Unit::TestCase
     expected = ["1-2,(1) <->a\nb</->cd\n",
                 "(2),1-2 cd<+>X\nY</+>e\n\n",
                 "3,3 e\n<!->f</!-><!+>F</!+>\n\n"]
-    assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").to_user_digest(user_tags, false))
+    assert_equal(expected, View.new(Difference.new(array1, array2), "US-ASCII", "LF").to_user_digest(user_tags, false))
   end
   def test_to_user_digest_multi()
     array1 = ["a", "\n", "b", "c", "d", "e", "\n", "f", "\n"]
@@ -539,7 +539,7 @@ class TC_View < Test::Unit::TestCase
     expected = ["1-2,(1) a\nbcd<->a\nb</->cd\n",
                 "(2),1-2 cde\ncd<+>X\nY</+>e\n\n",
                 "3,3 e\n<!->f</!->\ne\n<!+>F</!+>\n\n"]
-    assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").to_user_digest(user_tags, false))
+    assert_equal(expected, View.new(Difference.new(array1, array2), "US-ASCII", "LF").to_user_digest(user_tags, false))
   end
 
   def test_difference_whole()
@@ -551,7 +551,7 @@ class TC_View < Test::Unit::TestCase
                 [:common_elt_elt, ["e", "\n"], ["e", "\n"]],
                 [:change_elt, ["f"], ["F"]],
                 [:common_elt_elt, ["\n"], ["\n"]]]
-    assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").difference_whole)
+    assert_equal(expected, View.new(Difference.new(array1, array2), "US-ASCII", "LF").difference_whole)
   end
 
 #   def test_difference_digest()
@@ -560,7 +560,7 @@ class TC_View < Test::Unit::TestCase
 #     expected = [
 # # something
 #                ]
-#     assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").difference_digest)
+#     assert_equal(expected, View.new(Difference.new(array1, array2), "US-ASCII", "LF").difference_digest)
 #   end
 
   def teardown()
